/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Page.h"


/*
 * Constructs a chart.
 */
Chart::Chart(char anImageDirectory[], char aBarImage[], char aTitle[]) : Stat(anImageDirectory, aBarImage, aTitle)
{

}


/*
 * Generates a chart in a file with a log.
 */
void Chart::generate(FILE *aFile, Log *aLog)
{
  struct tm aDate;
  time_t endTime;
  int n[32], day[32], month[32];
  int i, max, tmp, nb;

  aDate = aLog->getEndDate();
  endTime = mktime(&aDate);
  aDate = aLog->getStartDate();
  aDate.tm_hour = 0;
  aDate.tm_min = 0;

  fputs("<H3>", aFile);
  fputs(title, aFile);
  fputs("</H3>\n<P>\n", aFile);
  fputs("<TABLE>\n", aFile);
  fputs("<TR>\n", aFile);

  max = 0;
  nb = 0;
  while (mktime(&aDate) < endTime)
    {
      n[nb] = getNumber(mktime(&aDate), aLog);
      if (n[nb] > max) max = n[nb];
      day[nb] = aDate.tm_mday;
      month[nb] = aDate.tm_mon + 1;
      nb++;
      aDate.tm_mday++;
    }

  for (i = 0; i < nb; i++)
    {
      fputs("<TD ALIGN=\"center\" VALIGN=\"bottom\">", aFile);
      fprintf(aFile, "%i", n[i]);
      fputs("<BR>", aFile);
      tmp = 0;
      if (max != 0) tmp = n[i] * 100 / max;
      fputs("<IMG SRC=\"", aFile);
      fputs(imageDirectory, aFile);
      fputs(barImage, aFile);
      fputs("\" WIDTH=\"20\" HEIGHT=\"", aFile);
      fprintf(aFile, "%i", tmp);
      fputs("\"></TD>\n", aFile);
    }

  fputs("</TR>\n<TR>\n", aFile);

  for (i = 0; i < nb; i++)
    {
      fputs("<TD ALIGN=\"center\">", aFile);
      fprintf(aFile, "%i", day[i]);
      fputs("/", aFile);
      fprintf(aFile, "%i", month[i]);
      fputs("</TD>\n", aFile);
    }

  fputs("</TR>\n", aFile);
  fputs("</TABLE>\n", aFile);
  fputs("<P>\n", aFile);
  fputs("<HR>\n", aFile);
}
