/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Config.h"


int Config::NBSTATS = 12;


char *Config::STAT[12] = {"Chart of the lines number",
			  "Chart of the users number",
			  "Chart of the lines number in a day",
			  "Chart of the users number in a day",
			  "Table of lines number",
			  "Table of actions number",
			  "Table of durations",
			  "Table of nicks number",
			  "Table of kicks number",
			  "Table of kicked users number",
			  "Table of topics number",
			  "Table of sessions number"};


char *Config::STATFR[12] = {"Graphique du nombre de lignes",
			    "Graphique du nombre de personnes",
			    "Graphique du nombre de lignes dans une journe",
			    "Graphique du nombre de personnes dans une journe",
			    "Tableau du nombre de lignes",
			    "Tableau du nombre d'actions",
			    "Tableau des dures",
			    "Tableau du nombre de pseudos",
			    "Tableau du nombre d'jection",
			    "Tableau du nombre de personnes jectes",
			    "Tableau du nombre de sujets",
			    "Tableau du nombre de sessions"
};


/*
 * Removes all stats used by the config.
 */
void Config::removeAll()
{
  for (int i = 0; i < NBSTATS; i++)
    {
      used[i] = -1;
    }
  nbUsed = 0;
}


/*
 * Constructs a config.
 */
Config::Config()
{
  char *tmp[12];
  char      *l;           // current language
  l = setlocale(LC_ALL, "");
  if (*l == 'f' && *(++l) == 'r') tmp = STATFR;
  else tmp = STAT;

  strcpy(logName, "\0");
  strcpy(fileName, "\0");
  page = new Page("#FFFFFF", "Statistics of #channel");
  stat[0] = new LinesChart("images/", "vbar.gif", tmp[0]);
  stat[1] = new UsersChart("images/", "vbar.gif", tmp[1], 12);
  stat[2] = new DailyLinesChart("images/", "vbar.gif", tmp[2], 1);
  stat[3] = new DailyUsersChart("images/", "vbar.gif", tmp[3], 1);
  stat[4] = new LineTable("images/", "hbar.gif", tmp[4], 20, 1);
  stat[5] = new ActionTable("images/", "hbar.gif", tmp[5], 10, 1);
  stat[6] = new DurationTable("images/", "hbar.gif", tmp[6], 10, 1);
  stat[7] = new NickTable("images/", "hbar.gif", tmp[7], 5, 1);
  stat[8] = new KickTable("images/", "hbar.gif", tmp[8], 10, 1);
  stat[9] = new KickedTable("images/", "hbar.gif", tmp[9], 10, 1);
  stat[10] = new TopicTable("images/", "hbar.gif", tmp[10], 5, 1);
  stat[11] = new SessionTable("images/", "hbar.gif", tmp[11], 10, 1);
  removeAll();
}


/*
 * Gets the index of the stat named aText.
 */
int Config::getNoStat(char aText[])
{
  int ret = -1;
  for (int i = 0; i < NBSTATS; i++)
    {
      if (!strcmp(aText, STAT[i]) || !strcmp(aText, STATFR[i])) ret = i;
    }
  return ret;
}


/*
 * Gets the number of stats.
 */
int Config::getNbStats()
{
  return NBSTATS;
}


/*
 * Gets the name of the stat at the index.
 */
char *Config::getStatName(int index)
{ 
  char      *l;           // current language
  char      *ret;         // name of the stat
  l = setlocale(LC_ALL, "");
  if (*l == 'f' && *(++l) == 'r') ret = STATFR[index];
  else ret = STAT[index];

  return ret;
}


/*
 * Gets the name of the stat used at the index.
 */
char *Config::getUsedStatName(int index)
{
  char      *l;           // current language
  char      *ret;         // name of the stat
  l = setlocale(LC_ALL, "");
  if (*l == 'f' && *(++l) == 'r') ret = STATFR[used[index]];
  else ret = STAT[used[index]];

  return ret;
}


/*
 * Gets the stat at the index.
 */
Stat *Config::getStat(int index)
{
  return stat[index];
}


/*
 * Gets the stat used at the index.
 */
Stat *Config::getUsedStat(int index)
{
  return stat[used[index]];
}


/*
 * Determines if the stat indexed is used by the config.
 */
bool Config::isUsed(int index)
{
  bool ret = 0;
  for (int i = 0; i < NBSTATS; i++)
    {
      if (used[i] == index) ret = 1;
    }
  return ret;
}


/*
 * Gets the number of stats used by the config.
 */
int Config::getNbUsed()
{
  return nbUsed;
}


/*
 * Gets the path of the log file.
 */
char *Config::getLogName()
{
  return logName;
}


/*
 * Gets the path of the web page.
 */
char *Config::getFileName()
{
  return fileName;
}


/*
 * Gets the page of the config.
 */
Page *Config::getPage()
{
  return page;
}


/*
 * Sets the path of the log file.
 */
void Config::setLogName(char aLogName[])
{
  strcpy(logName, aLogName);
}


/*
 * Sets the path of the web page.
 */
void Config::setFileName(char aFileName[])
{
  strcpy(fileName, aFileName);
}


/*
 * Adds a stat for the config.
 */
void Config::add(char text[])
{
  used[nbUsed] = getNoStat(text);
  nbUsed++;
}


/*
 * removes a used stat at the index.
 */
void Config::remove(int index)
{
  int i = 0;
  for (i = index; i < NBSTATS - 1; i++)
    {
      used[i] = used[i + 1];
    }
  nbUsed--;
  used[nbUsed] = -1;
}


/*
 * Increases the used stat indexed for one row.
 */
void Config::go_up(int index)
{
  int tmp;
  tmp = used[index];
  used[index] = used[index - 1];
  used[index - 1] = tmp;
}


/*
 * Decreases the used stat indexed for one row.
 */
void Config::go_down(int index)
{
  int tmp;
  tmp = used[index];
  used[index] = used[index + 1];
  used[index + 1] = tmp;
}


/*
 * Saves the config in a file.
 */
bool Config::save(char filename[])
{
  FILE *file;

  file = fopen(filename, "w");
  if (file == NULL) return 0;

  fputs("xstat configuration file\n", file);
  fputs("[Main properties]\n", file);
  fputs("LogFileName:", file);
  fputs(logName, file);
  fputs("\nPageFileName:", file);
  fputs(fileName, file);
  fputs("\nTitle:", file);
  fputs(page->getTitle(), file);
  fputs("\nBackground:", file);
  fputs(page->getBackground(), file);
  fputs("\nRelativeImageDirectory:", file);
  fputs(page->getImageDirectory(), file);
  
  fputs("\n[List of used stats]\n", file);
  for (int i = 0; i < nbUsed; i++)
    {
      fputs(STAT[used[i]], file);
      fputs("\n", file);
    }
  
  for (int i = 0; i < NBSTATS; i++)
    {
      fputs("[", file);
      fputs(STAT[i], file);
      fputs("]\nTitle:", file);
      fputs(stat[i]->getTitle(), file);
      fputs("\nBarImage:", file);
      fputs(stat[i]->getBarImage(), file);
      fputs("\nRelativeImageDirectory:", file);
      fputs(stat[i]->getImageDirectory(), file);
      fputs("\n", file);
      if (i == 1)
	{
	  fputs("HourOfTheDay:", file);
	  fprintf(file, "%i\n", stat[i]->getHour());
	}
      if (i >= 2 && i <= 3)
	{
	  fputs("IntervalOfHours:", file);
	  fprintf(file, "%i\n", stat[i]->getInterval());
	}
      if (i >= 4)
	{
	  fputs("MaximumNumberOfUsers:", file);
	  fprintf(file, "%i\n", stat[i]->getNbMaxUsers());
	  fputs("ShowAnExample:", file);
	  fprintf(file, "%i\n", stat[i]->hasExamples());
	}
    }
  fclose(file);
  return 1;
}


/*
 * Saves the config in the file '$HOME/.xstat'.
 */
bool Config::saveCurrent()
{
  char *text = new char[50];
  strcpy(text, getenv("HOME"));
  strcat(text, "/.xstat");
  return save(text);
}


/*
 * Loads the config from a file.
 */
int Config::load(char filename[])
{
  FILE *file;
  char *text = new char[80];

  //printf("File to open : %s\n", filename);
  file = fopen(filename, "r");
  if (file == NULL) return 0;

  text = fgets(text, 80, file);
  if (strcmp(text, "xstat configuration file\n")) return 1;
  removeAll();

  text = fgets(text, 80, file);
  while (!feof(file))
    {
      //printf("Test : %s", text);
      text = strtok(text, "[]");
      int index = getNoStat(text);
      if (index != -1)
	{
	  //printf("catchStat\n");
	  char *field = new char[50];
	  char *data = new char[50];
	  char *aTitle = stat[index]->getTitle();
	  char *aBarImage = stat[index]->getBarImage();
	  char *anImageDirectory = stat[index]->getImageDirectory();
	  int info;
	  if (index == 1) info = stat[index]->getHour();
	  else if (index >= 2 && index <= 3) info = stat[index]->getInterval();
	  else info = stat[index]->getNbMaxUsers();
	  bool anExample= stat[index]->hasExamples();
	  
	  text = fgets(text, 80, file);
	  while (text != NULL)
	    {
	      //printf("%s", text);
	      field = strtok(text, ":");
	      //printf("Field : %s\n", field);
	      data = strtok(NULL, "\n");
	      if (data == NULL) data = "\0";
	      //printf("Data : %s\n", data);
	      if (!strcmp(field, "Title")) strcpy(aTitle, data);
	      else if (!strcmp(field, "BarImage")) strcpy(aBarImage, data);
	      else if (!strcmp(field, "RelativeImageDirectory")) strcpy(anImageDirectory, data);
	      else if (!strcmp(field, "MaximumNumberOfUsers")) info = atoi(data);
	      else if (!strcmp(field, "ShowAnExample")) anExample = atoi(data);
	      else if (!strcmp(field, "HourOfTheDay")) info = atoi(data);
	      else if (!strcmp(field, "IntervalOfHours")) info = atoi(data);
	      else break;
	      text = fgets(text, 80, file);
	    }

	  if (index == 0) stat[index]->configure(anImageDirectory, aBarImage, aTitle);
	  else if (index >= 1 && index <= 3) stat[index]->configure(anImageDirectory, aBarImage, aTitle, info);
	  else stat[index]->configure(anImageDirectory, aBarImage, aTitle, info, anExample);
	}

      else if (!strcmp(text, "Main properties")) 
	{
	  //printf("catchMainProperties\n");
	  char *field = new char[50];
	  char *data = new char[50];
	  char *aTitle = page->getTitle();
	  char *aBackground = page->getBackground();
	  char *aImageDirectory = page->getImageDirectory();
	  
	  text = fgets(text, 80, file);
	  while (text != NULL) 
	    {
	      //printf("%s", text);
	      field = strtok(text, ":");
	      //  printf("Field : %s\n", field);
	      data = strtok(NULL, "\n");
	      if (data == NULL) data = "\0";
	      //printf("Data : %s\n", data);
	      if (!strcmp(field, "LogFileName")) strcpy(logName, data);
	      else if (!strcmp(field, "PageFileName")) strcpy(fileName, data);
	      else if (!strcmp(field, "Title")) strcpy(aTitle, data);
	      else if (!strcmp(field, "Background")) strcpy(aBackground, data);
	      else if (!strcmp(field, "RelativeImageDirectory")) strcpy(aImageDirectory, data);
	      else break;
	      text = fgets(text, 80, file);
	    }
	  page->configure(aImageDirectory, aBackground, aTitle);
	}

      else if (!strcmp(text, "List of used stats")) 
	{
	  //printf("catchListOfUsedStats\n");
	  text = fgets(text, 80, file);
	  //printf("%s", text);
	  text = strtok(text, "\n");
	  while (getNoStat(text) > -1)
	    {
	      //printf("test : %i\n", getNoStat(text));
	      add(text);
	      text = fgets(text, 80, file);
	      //  printf("%s", text);
	      text = strtok(text, "\n");
	    }
	}

      else 
	{
	  text = fgets(text, 80, file);
	}
    }
  return 2;
}


/*
 * Loads a config from the file '$HOME/.xstat'.
 */
int Config::loadCurrent()
{
  char *text = new char[50];
  strcpy(text, getenv("HOME"));
  strcat(text, "/.xstat");
  return load(text);
}
