/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Page.h"


/*
 * Constructs a daily chart.
 */
DailyChart::DailyChart(char anImageDirectory[], char aBarImage[], char aTitle[], int anInterval) : Stat(anImageDirectory, aBarImage, aTitle)
{
  interval = anInterval;
}


/*
 * Gets the interval of hours of the daily chart.
 */
int DailyChart::getInterval()
{
  return interval;
}


/*
 * Configures the daily chart.
 */
void DailyChart::configure(char anImageDirectory[], char aBarImage[], char aTitle[], int anInterval)
{
  strcpy(imageDirectory, anImageDirectory);
  strcpy(barImage, aBarImage);
  strcpy(title, aTitle);
  interval = anInterval;
}


/*
 * Generates a daily chart in the file with a log.
 */
void DailyChart::generate(FILE *aFile, Log *aLog)
{
  int n[24];
  int i, max, tmp;

  fputs("<H3>", aFile);
  fputs(title, aFile);
  fputs("</H3>\n<P>\n", aFile);
  fputs("<TABLE>\n", aFile);
  fputs("<TR>\n", aFile);

  max = 0;
  for (i = 0; i < 24; i += interval)
    {
      n[i] = getNumber(i, aLog);
      if (n[i] > max) max = n[i];
    }

  for (i = 0; i < 24; i += interval)
    {
      fputs("<TD ALIGN=\"center\" VALIGN=\"bottom\">", aFile);
      fprintf(aFile, "%i", n[i]);
      fputs("<BR>", aFile);
      tmp = 0;
      if (max != 0) tmp = n[i] * 100 / max;
      fputs("<IMG SRC=\"", aFile);
      fputs(imageDirectory, aFile);
      fputs(barImage, aFile);
      fputs("\" WIDTH=\"20\" HEIGHT=\"", aFile);
      fprintf(aFile, "%i", tmp);
      fputs("\"></TD>\n", aFile);
    }

  fputs("</TR>\n<TR>\n", aFile);

  for (i = 0; i < 24; i += interval)
    {
      fputs("<TD ALIGN=\"center\">", aFile);
      fprintf(aFile, "%i", i);
      fputs("</TD>\n", aFile);
    }
  fputs("</TR>\n", aFile);
  fputs("</TABLE>\n", aFile);
  fputs("<P>\n", aFile);
  fputs("<HR>\n", aFile);
}
