/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Log.h"


/*
 * Gives a substring of the specified string with the index start and the size.
 */
char *Log::substring(char string[], int start, int size)
{
  int i;
  static char tmp[5];
  for (i = 0; i < size; i++)
    {
      tmp[i] = string[start + i];
    }
  tmp[size] = '\0';
  return tmp;
}


/*
 * Gets back the date of start.
 */
int Log::catchStartDate(char string[])
{
  char *s;
  time_t tmp;

  s = substring(string, 15, 3);
  if (!strcmp(s, "Sun\0")) startDate.tm_wday = 0;
  else if (!strcmp(s, "Mon\0")) startDate.tm_wday = 1;
  else if (!strcmp(s, "Tue\0")) startDate.tm_wday = 2;
  else if (!strcmp(s, "Wed\0")) startDate.tm_wday = 3;
  else if (!strcmp(s, "Thu\0")) startDate.tm_wday = 4;
  else if (!strcmp(s, "Fri\0")) startDate.tm_wday = 5;
  else if (!strcmp(s, "Sat\0")) startDate.tm_wday = 6;
  else startDate.tm_wday = -1;

  s = substring(string, 19, 3);
  if (!strcmp(s, "Jan\0")) startDate.tm_mon = 0;
  else if (!strcmp(s, "Feb\0")) startDate.tm_mon = 1;
  else if (!strcmp(s, "Mar\0")) startDate.tm_mon = 2;
  else if (!strcmp(s, "Apr\0")) startDate.tm_mon = 3;
  else if (!strcmp(s, "May\0")) startDate.tm_mon = 4;
  else if (!strcmp(s, "Jun\0")) startDate.tm_mon = 5;
  else if (!strcmp(s, "Jul\0")) startDate.tm_mon = 6;
  else if (!strcmp(s, "Aug\0")) startDate.tm_mon = 7;
  else if (!strcmp(s, "Sep\0")) startDate.tm_mon = 8;
  else if (!strcmp(s, "Oct\0")) startDate.tm_mon = 9;
  else if (!strcmp(s, "Nov\0")) startDate.tm_mon = 10;
  else if (!strcmp(s, "Dec\0")) startDate.tm_mon = 11;
  else startDate.tm_mon = -1;
  
  s = substring(string, 23, 2);
  startDate.tm_mday = atoi(s);

  s = substring(string, 26, 2);
  startDate.tm_hour = atoi(s);

  s = substring(string, 29, 2);
  startDate.tm_min = atoi(s);

  startDate.tm_sec = 0;

  s = substring(string, 35, 4);
  startDate.tm_year = atoi(s) - 1900;

  s = asctime(&startDate);
  tmp = mktime(&startDate);
  currentDate = startDate;
  period[nbPeriod] = new Period(tmp);
  if (tmp == -1) return(1);
  else return(0);
}


/**
 * Gets back the current date in the log.
 */
int Log::catchCurrentDate(char string[])
{
  int ret;
  char *s;
  int hour;
  int min;
  time_t tmp;

  s = substring(string, 1, 2);
  hour = atoi(s);

  s = substring(string, 4, 2);
  min = atoi(s);

  while (hour != currentDate.tm_hour || min < currentDate.tm_min)
    {
      currentDate.tm_hour++;
      currentDate.tm_min = 0;
      tmp = mktime(&currentDate);
      nbPeriod++;
      period[nbPeriod] = new Period(tmp);
    }

  currentDate.tm_min = min;
  tmp = mktime(&currentDate);
  if (tmp == -1) return(1);
  else return(0);
}


/*
 * Gets back the system messages in the log.
 */
int Log::catchInformation(char string[])
{
  //printf("CatchInformation\n");
  User *anUser;
  char *nick;
  char *address;
  char *type;
  char *info;
  char *info2;
  char copy[1000];
  strcpy(copy, string);

  nick = strtok(string, " ");
  nick = strtok(NULL, " ");
  nick = strtok(NULL, " ");
  
  //printf("Current nick : %s\n", nick);
  address = strtok(NULL, " ");
  //printf("Current address : %s\n", address);
  type = strtok(NULL, " ");
  type = strtok(NULL, " ");
  //printf("Current type : %s\n", type);

  if (nick != NULL && address != NULL && type != NULL)
    {
      if (!strcmp(type, "joined\0"))
	{     
	  info = strtok(address, "(@");
	  info2 = strtok(NULL, ".");
	  info2 = strtok(NULL, ")");
	  strcpy(copy, info2);
	  type = strtok(copy, ".");
	  type = strtok(NULL, ".");
	  type = strtok(NULL, "");
	  if (type != NULL)
	    {
	      type = strtok(info2, ".");
	      info2 = strtok(NULL, "");
	    }
	  //printf("Current name : %s\n", info);
	  //printf("Current domain : %s\n", info2);
	  //printf("Current number of users : %i\n", nbUser);
	  
	  anUser = searchUser(info, info2);
	  //printf("User has been searched\n");
	  if (anUser == NULL)
	    {
	      //printf("User has not been found\n");
	      user[nbUser] = new User(info, info2);
	      //printf("User has been created\n");
	      anUser = user[nbUser];
	      //printf("User has been copied\n");
	      nbUser++;
	      user[nbUser] = NULL;
	    }
	  anUser->joins(nick, mktime(&currentDate));
	  //printf("User has joined\n");
	}
      else if (!strcmp(type, "known\0"))
	{
	  info = strtok(NULL, " ");
	  info = strtok(NULL, "\n\r");
	  
	  //printf("searchUser : %s\n", nick);
	  anUser = searchUser(nick);
	  if (anUser != NULL)
	    {
	      //printf("leaves\n");
	      anUser->leaves(mktime(&currentDate));
	      //printf("joins\n");
	      anUser->joins(info, mktime(&currentDate));
	    }
	  //printf("Second nick : %s\n", info);
	}
      else if (!strcmp(type, "to\0"))
	{
	  info = strtok(NULL, "\n\r");
	  
	  anUser = searchUser(nick);
	  if (anUser != NULL)
	    {
	      anUser->changesTopic(info);
	    }
	  //printf("Topic : %s\n", info);
	}
      else if (!strcmp(type, "by\0"))
	{
	  info = strtok(NULL, " ");
	  info2 = strtok(copy, " ");
	  info2 = strtok(NULL, " ");
	  info2 = strtok(NULL, "\n\r");
	  
	  anUser = searchUser(nick);
	  if (anUser != NULL)
	    {
	      anUser->isKicked(info2, mktime(&currentDate));
	    }
	  anUser = searchUser(info);
	  if (anUser != NULL)
	    {
	      anUser->kicks(info2);
	    }
	  //printf("Second nick : %s\n", info);
	  //printf("Reason : %s\n", info2);
	}
      else if (!strcmp(type, "left\0"))
	{
	  //printf("searchUser : %s\n", nick);
	  anUser = searchUser(nick);
	  if (anUser != NULL)
	    {
	      //printf("leaves\n");
	      anUser->leaves(mktime(&currentDate));
	    }

	  //printf("Current address : %s\n", strtok(address, "()"));
	}
      else if (!strcmp(type, "IRC\0"))
	{
	  info = strtok(copy, " ");
	  info = strtok(NULL, " ");
	  info = strtok(NULL, "\n\r");
	  //printf("searchUser : %s\n", nick);
	  anUser = searchUser(nick);
	  if (anUser != NULL)
	    {
	      //printf("leavesIRC\n");
	      anUser->leavesIRC(info, mktime(&currentDate));
	    }
	  //printf("Sentence : %s\n", info);
	}
    }

  if (nick == NULL) return(1);
  else return(0);
}


/*
 * Gets back the action of an user in the log.
 */
int Log::catchActionNick(char string[])
{
  char *nick;
  char *sentence;
  char copy[1000];
  User *anUser;
  strcpy(copy, string);
  
  nick = strtok(string, " ");
  nick = strtok(NULL, " ");
  nick = strtok(NULL, " ");
  sentence = strtok(copy, " ");
  sentence = strtok(NULL, " ");
  sentence = strtok(NULL, "\n");

  period[nbPeriod]->addLine();
  anUser = searchUser(nick);
  if (anUser != NULL) anUser->doesAction(sentence);
  
  //printf("Current nick : %s\n", nick);
  //printf("Current sentence : %s\n", sentence);
  if (nick == NULL || sentence == NULL) return(1);
  else return(0);
}


/*
 * Gets back a 'classic' sentence of an user in the log.
 */
int Log::catchSpeakNick(char string[])
{
  char *nick;
  char *sentence;
  User *anUser;

  nick = strtok(string, "<>");
  nick = strtok(NULL, "<>");
  sentence = strtok(NULL, "\n");

  if (nick != NULL)
    {
      period[nbPeriod]->addLine();
      anUser = searchUser(nick);
      if (anUser != NULL) anUser->speaks(sentence);
      
      //printf("Current nick : %s\n", nick);
      //printf("Current sentence : %s\n", sentence); 
      return(0);
    }
  else return(1);
}


/**
 * Gets the user who has the nick aNick.
 */
User *Log::searchUser(char aNick[])
{
  int i;
  User *ret;

  ret = NULL;
  //if (!strcmp(aNick, "nico--\0")) printf("nbUser : %i\n", nbUser);
  for (i = 0; i < nbUser; i++)
    {
      //if (user[i] == NULL) printf("can't compare to nick %i\n", i);
      if (user[i]->compareNick(aNick)) ret = user[i];
    }
  return ret;
}


/*
 * Gets the user who has the name aName and the domain aDomain.
 */
User *Log::searchUser(char aName[], char aDomain[])
{
  int i;
  User *ret;

  ret = NULL;
  for (i = 0; i < nbUser; i++)
    {
      if (user[i]->compareAddress(aName, aDomain)) ret = user[i];
    }

  return ret;
}


/*
 * Constructs a log.
 */
Log::Log()
{
  nbPeriod = 0;
  nbUser = 0;
}


/*
 * Destroys the log.
 */
Log::~Log()
{
  int i;
  for (i = 0; i < nbPeriod ; i++)
    {
      delete period[i];
    }
  for (i = 0; i < nbUser ; i++)
    {
      delete user[i];
    }
}


/*
 * Analyses a log file.
 */
int Log::analyse(char logFile[50])
{
  FILE *file;
  char string[1000];
  char *s;
  int i, tmp;

  srand(time(0));
  file = fopen(logFile, "r");
  if (file == NULL) return(-1);
  //printf("File is open\n");

  fgets(string, 1000, file);
  printf("\r1");
  if (catchStartDate(string)) return(1);
  //printf("Date of start : %s", asctime(&startDate));

  i = 2;
  fgets(string, 1000, file);

  while (!feof(file) && string[0] == '[')
    {
      printf("\r%i", i);
      //printf("%i\n", i);
      if (catchCurrentDate(string)) return(i);
      s = substring(string, 8, 2);
      if (!strcmp(s, "**\0")) tmp = catchInformation(string);
      else if (!strcmp(s, "* \0")) tmp = catchActionNick(string);
      else tmp = catchSpeakNick(string);
      if (tmp) return(i);
      i++;
      fgets(string, 1000, file);
    }
  nbPeriod++;
  fclose(file);

  return(0);
}


/*
 * Gets the number of users.
 */
int Log::getNbUsers()
{
  return nbUser;
}


/*
 * Gets the number of hours of the log.
 */
int Log::getNbPeriods()
{
  return nbPeriod;
}


/*
 * Gets the date of start.
 */
struct tm Log::getStartDate()
{
  return startDate;
}


/*
 * Gets the date of end.
 */
struct tm Log::getEndDate()
{
  return currentDate;
}


/*
 * Gets the number of sessions.
 */
int Log::getNbSessions()
{
  int ret = 0;
  int i;
  for (i = 0; i < nbUser; i++)
    {
      ret += user[i]->getNbSessions();
    }
  return ret;
}


/*
 * Gets the number of nicks.
 */
int  Log::getNbNicks()
{
  int ret = 0;
  int i;  
  for (i = 0; i < nbUser; i++)
    {
      ret += user[i]->getNbNicks();
    }
  return ret;
}


/*
 * Gets the number of lines.
 */
int  Log::getNbLines()
{
  int ret = 0;
  int i;  
  for (i = 0; i < nbUser; i++)
    {
      ret += user[i]->getNbLines();
    }
  return ret;
}


/*
 * Gets the number of actions.
 */
int  Log::getNbActions()
{
  int ret = 0;
  int i;  
  for (i = 0; i < nbUser; i++)
    {
      ret += user[i]->getNbActions();
    }
  return ret;
}


/*
 * Gets the number of topics changed.
 */
int  Log::getNbTopics()
{
  int ret = 0;
  int i;  
  for (i = 0; i < nbUser; i++)
    {
      ret += user[i]->getNbTopics();
    }
  return ret;
}


/*
 * Gets the number of kicks.
 */
int  Log::getNbKicks()
{
  int ret = 0;
  int i;  
  for (i = 0; i < nbUser; i++)
    {
      ret += user[i]->getNbKickeds();
    }
  return ret;
}


/*
 * Gets the number of users at the specified date.
 */
int Log::getNbUsers(time_t aDate)
{
  int ret = 0;
  int i;
  for (i = 0; i < nbUser; i++)
    {
      if (user[i]->wasPresent(aDate)) ret++;
    }
  return ret;
}


/*
 * Gets the number of users at a specified hour of the day.
 */
int Log::getDailyNbUsers(int anHour)
{
  int ret = 0;
  int nb = 0;
  struct tm aDate;
  time_t aTime;

  if (anHour >= 0 && anHour < 24)
    {
      aDate = startDate;
      aDate.tm_hour = anHour;
      aDate.tm_min = 0;
      aTime = mktime(&aDate);
      
      while (aTime <= mktime(&currentDate))
	{
	  // printf("%i\t", getNbUsers(aTime));
	  ret += getNbUsers(aTime);
	  if (aTime >= mktime(&startDate)) nb++;
	  aDate.tm_mday++;
	  aTime = mktime(&aDate);
	}
    }
  // printf("ret = %i", ret);
  if (nb != 0) ret = ret / nb;
  return ret;
}


/*
 * Gets the number of lines between the specified dates.
 */
int Log::getNbLines(time_t startTime, time_t endTime)
{
  int ret = 0;
  int i = 0;

  if ((startTime < endTime) && (startTime <= mktime(&currentDate)) && (endTime > mktime(&startDate)))
    {
      while (i < nbPeriod && period[i]->getDate() < startTime)
	{
	  i++;
	}
      
      while (i < nbPeriod && period[i]->getDate() <= mktime(&currentDate) && period[i]->getDate() < endTime)
	{
	  // printf("%i\t", period[i]->getNbLines());
	  ret += period[i]->getNbLines();
	  i++;
	}
    }
  return ret;
}


/*
 * Gets the number of lines between the specified hours of the day.
 */
int Log::getDailyNbLines(int startHour, int endHour)
{
  int ret = 0;
  int nb = 1;
  struct tm stDate, endDate;
  time_t stTime, endTime;

  if (startHour >= 0 && startHour < 24 && endHour >= 0 && endHour < 24 && startHour < endHour)
    { 
      nb = 0;
      stDate = startDate;
      stDate.tm_hour = startHour;
      stDate.tm_min = 0;
      stTime = mktime(&stDate);
      endDate = startDate;
      endDate.tm_hour = endHour;
      endDate.tm_min = 0;
      endTime = mktime(&endDate);
     
      while (stTime <= mktime(&currentDate))
	{
	  ret += getNbLines(stTime, endTime);
	  if (endTime > mktime(&startDate)) nb++;
	  stDate.tm_mday++;
	  stTime = mktime(&stDate);
	  endDate.tm_mday++;
	  endTime = mktime(&endDate);
	}
    }
  // printf("ret = %i", ret);
  if (nb != 0) ret = ret / nb;
  return ret;
}


/*
 * Gets the user at the index.
 */
User *Log::getUser(int index)
{
  return user[index];
}
