/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Page.h"


/*
 * Constructs a page with a background image.
 */
Page::Page(char anImageDirectory[], char aBackground[], char aTitle[])
{
  strcpy(imageDirectory, anImageDirectory);
  strcpy(background, aBackground);
  strcpy(title, aTitle);
}


/*
 * Constructs a page with a background color.
 */
Page::Page(char aColor[], char aTitle[])
{
  strcpy(imageDirectory, "\0");
  strcpy(background, aColor);
  strcpy(title, aTitle);
}


/*
 * Gets the relative image directory.
 */
char *Page::getImageDirectory()
{
  return imageDirectory;
}


/*
 * Gets the background of the page.
 */
char *Page::getBackground()
{
  return background;
}


/*
 * Gets the title of the page.
 */
char *Page::getTitle()
{
  return title;
}


/*
 * Determines if the page has a background image.
 */
bool Page::hasImage()
{
  return (strcmp(imageDirectory, "\0"));
}


/*
 * Configures a page with a background image.
 */
void Page::configure(char anImageDirectory[], char aBackground[], char aTitle[])
{
  strcpy(imageDirectory, anImageDirectory);
  strcpy(background, aBackground);
  strcpy(title, aTitle);
}


/*
 * Configures a page with a background color.
 */
void Page::configure(char aColor[], char aTitle[])
{
  strcpy(imageDirectory, "\0");
  strcpy(background, aColor);
  strcpy(title, aTitle);
}


/*
 * Generates the head of the web page.
 */
void Page::makeHead(FILE *aFile, Log *log)
{
  struct tm aDate;
  char *str = new char[30];
  setlocale(LC_ALL, "");

  fputs("<HTML>\n", aFile);

  fputs("<HEAD>\n", aFile);
  fputs("<META NAME=\"GENERATOR\" CONTENT=\"Xstat\">\n", aFile);
  fputs("<TITLE>", aFile);
  fputs(title, aFile);
  fputs("</TITLE>\n", aFile);
  fputs("</HEAD>\n", aFile);

  fputs("<BODY ", aFile);
  if (!strcmp(imageDirectory, "\0"))
    {
      fputs("BGCOLOR=\"", aFile);
    }
  else
    {
      fputs("BACKGROUND=\"", aFile);
      fputs(imageDirectory, aFile);
    }
  fputs(background, aFile);
  fputs("\">\n", aFile);
  fputs("<CENTER><H1>", aFile);
  fputs(title, aFile);
  fputs("</H1>\n", aFile);
  fputs("<H5>", aFile);
  aDate = log->getStartDate();
  strftime(str, 30, "%c", &aDate);
  fputs(str, aFile);
  fputs(" - ", aFile);
  aDate = log->getEndDate();
  strftime(str, 30, "%c", &aDate);
  fputs(str, aFile);
  fputs("</H5>\n", aFile);
  fputs("<HR>\n", aFile);
}


/*
 * Generates the bottom of the web page.
 */
void Page::makeBottom(FILE *aFile)
{  
  struct tm *aDate;
  time_t aTime;
  char *str = new char[30];
  char *messages[2];      // messages
  char      *l;           // current language
  // Initializes messages
  l = setlocale(LC_ALL, "");
  if (*l == 'f' && *(++l) == 'r')
    {
      messages[0] = "Statistiques g&eacute;n&eacute;r&eacute;es avec <A HREF=\"http://upsilon.free.fr/xstat/indexfr.html\">Xstat</A> le ";
      messages[1] = "Reportez les bogues &agrave; <A HREF=\"mailto:julien.lesouef@free.fr\">Julien Lesouef</A>\n";
    }
  else
    {
      messages[0] = "Statistics generated with <A HREF=\"http://upsilon.free.fr/xstat/index.html\">Xstat</A> on ";
      messages[1] = "Report bugs to <A HREF=\"mailto:julien.lesouef@free.fr\">Julien Lesouef</A>\n";
    }

  fputs(messages[0], aFile);
  aTime = time(NULL);
  aDate = localtime(&aTime);
  strftime(str, 30, "%c", aDate);
  fputs(str, aFile);
  fputs("<P>\n", aFile);
  fputs(messages[1], aFile);
  fputs("</CENTER>\n", aFile);
  fputs("</BODY>\n", aFile);
  fputs("</HTML>\n", aFile);
}
