/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Session.h"


/**
 * Constructs a session with a nick name and a time.
 */
Session::Session(char aNick[], time_t aTime)
{
  strcpy(nick, aNick);
  joinTime = aTime;
  quitTime = aTime;
}


/**
 * Gives the time of the session end.
 */
void Session::leaves(time_t aTime)
{
  quitTime = aTime;
}


/**
 * Gets the nickname of the session.
 */
char *Session::getNick()
{
  return nick;
}


/**
 * Determines if the session was present at the time specified.
 */
bool Session::wasPresent(time_t aTime)
{
  return (aTime >= joinTime && aTime <= quitTime);
}


/**
 * Gets the duration of the session.
 */
time_t Session::getDuration()
{
  return (time_t) difftime(quitTime, joinTime);
}


/**
 * Determines if the session has ended.
 */
bool Session::hasLeft()
{
  return (quitTime != joinTime);
}
