/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Page.h"


/*
 * Gets the most used nick of the user indexed by index.
 */
char *Table::getNick(int index, Log *aLog)
{
  return aLog->getUser(index)->getMostUsedNick();
}


/*
 * Constructs a table.
 */
Table::Table(char anImageDirectory[], char aBarImage[], char aTitle[], int aNbMaxUsers, bool hasSomeSentences) : Stat(anImageDirectory, aBarImage, aTitle)
{
  nbMaxUsers = aNbMaxUsers;
  hasSentences = hasSomeSentences;
}


/*
 * Gets the maximum number of users displayed in the table.
 */
int Table::getNbMaxUsers()
{
  return nbMaxUsers;
}


/*
 * Determines if the table must display examples.
 */
bool Table::hasExamples()
{
  return hasSentences;
}


/*
 * Configures the table.
 */
void Table::configure(char anImageDirectory[], char aBarImage[], char aTitle[], int aNbMaxUsers, bool hasSomeSentences)
{  
  strcpy(imageDirectory, anImageDirectory);
  strcpy(barImage, aBarImage);
  strcpy(title, aTitle);
  nbMaxUsers = aNbMaxUsers;
  hasSentences = hasSomeSentences;
}


/*
 * Generates a table.
 */
void Table::generate(FILE *aFile, Log *aLog)
{
  int no[aLog->getNbUsers()];
  int i, j, imax, tmp;

  for (i = 0; i < aLog->getNbUsers(); i++)
    {
      no[i] = i;
    }

  fputs("<H3>", aFile);
  fputs(title, aFile);
  fputs("</H3>\n<P>\n", aFile);
  fputs("<TABLE BORDER=\"1\" CELLPADDING=\"3\">\n", aFile);

  for (i = 0; i < nbMaxUsers; i++)
    {
      if (i >= aLog->getNbUsers()) break;
      imax = i;
      for (j = i; j < aLog->getNbUsers(); j++)
	{
	  if (getNumber(no[j], aLog) > getNumber(no[imax], aLog)) imax = j;
	}
      tmp = no[imax];
      no[imax] = no[i];
      no[i] = tmp;

      if (getNumber(no[i], aLog) == 0) break;
      fputs("<TR>\n<TD>", aFile);
      fprintf(aFile, "%i", i + 1);
      fputs("</TD>\n<TD>", aFile);
      fputs(getNick(no[i], aLog), aFile);
      fputs("</TD>\n<TD>", aFile);

      tmp = getNumber(no[i], aLog) * 100 / getNumber(no[0], aLog);
      fputs("<IMG SRC=\"", aFile);
      fputs(imageDirectory, aFile);
      fputs(barImage, aFile);
      fputs("\" WIDTH=\"", aFile);
      fprintf(aFile, "%i", tmp);
      fputs("\" HEIGHT=\"15\"> ", aFile);
      fprintf(aFile, "%i", getNumber(no[i], aLog));
      if (hasSentences)
	{
	  fputs("</TD>\n<TD>", aFile);
	  fputs(getSentence(no[i], aLog), aFile);
	}
      fputs("</TD>\n</TR>\n", aFile);
    }

  fputs("</TABLE>\n", aFile);
  fputs("<P>\n", aFile);
  fputs("<HR>\n", aFile);
}
