/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include <stdio.h>
#include <stdlib.h>
#include "Config.h"


void display(Config *aConfig)
{
  for (int i = 0; i < aConfig->getNbUsed(); i++)
    {
      printf("\t%s\n", aConfig->getUsedStatName(i));
    }
}


void main(void)
{
  Config *config;
  Config *config2;
  int i;
  char *text = new char[50];

  printf("Construct a config\n");
  config = new Config();
  
  printf("\n");
  printf("Log name : %s\n", config->getLogName());
  printf("File name : %s\n", config->getFileName());
  printf("Title of the page : %s\n", config->getPage()->getTitle());

  printf("\n");
  config->setLogName("test.log");
  config->setFileName("stat.html");
  config->getPage()->configure("images/", "back.jpeg", "Statistics generated with test.log");
  config->getStat(4)->configure("images/", "hbar.gif", "Who is the most talkative ?", 30);

  printf("\n");
  printf("Log name : %s\n", config->getLogName());
  printf("File name : %s\n", config->getFileName());
  printf("Title of the page : %s\n", config->getPage()->getTitle());
  printf("Title of the stat 4 : %s\n", config->getStat(4)->getTitle());
  printf("Bar image of the stat 4 : %s\n", config->getStat(4)->getBarImage());
  printf("Relative image directory of the stat 4 : %s\n", config->getStat(4)->getImageDirectory());
  printf("Maximum number of users of the stat 4 : %i\n", config->getStat(4)->getNbMaxUsers());

  printf("Index of the stat Table of durations : %i\n", config->getNoStat("Table of durations"));
  printf("Index of the stat Table of users : %i\n", config->getNoStat("Table of users"));
  printf("Numbers of stats : %i\n", config->getNbStats());
  printf("Name of the stat 0 : %s\n", config->getStatName(0));
  printf("Title of the stat 0 : %s\n", config->getStat(0)->getTitle());
  printf("Number of used stats : %i\n", config->getNbUsed());

  printf("Add 5 stats for the config\n");
  config->add("Table of durations");
  config->add("Chart of the users number");
  config->add("Table of lines number");
  config->add("Chart of the lines number in a day");
  config->add("Table of sessions number");
  
  printf("Number of used stats : %i\n", config->getNbUsed());
  display(config);
  printf("Name of the used stat 0 : %s\n", config->getUsedStatName(0));
  printf("Title of the used stat 0 : %s\n", config->getUsedStat(0)->getTitle());
  printf("Is the stat 0 used : %i\n", config->isUsed(0));
  printf("Is the stat 1 used : %i\n", config->isUsed(1));

  printf("go up the stat 1\n");
  config->go_up(1);
  printf("go down the stat 3\n");
  config->go_down(3);
  display(config);

  printf("Remove the used stat 2\n");
  config->remove(2);
  printf("Number of used stats : %i\n", config->getNbUsed());
  display(config);

  printf("Save the config : %i\n", config->saveCurrent());
  printf("Delete the config\n");
  delete config;

  printf("Construct a config\n");
  config2 = new Config();
  printf("Load the config : %i\n", config2->loadCurrent());
  printf("\n");
  printf("Log name : %s\n", config2->getLogName());
  printf("File name : %s\n", config2->getFileName());
  printf("Title of the page : %s\n", config2->getPage()->getTitle());
  printf("Background : %s\n", config2->getPage()->getBackground());
  printf("Relative image directory : %s\n", config2->getPage()->getImageDirectory());
  display(config2);
  printf("Title of the stat 4 : %s\n", config->getStat(4)->getTitle());
  printf("Bar image of the stat 4 : %s\n", config->getStat(4)->getBarImage());
  printf("Relative image directory of the stat 4 : %s\n", config->getStat(4)->getImageDirectory());
  printf("Maximum number of users of the stat 4 : %i\n", config->getStat(4)->getNbMaxUsers());

  printf("Delete the config\n");
  delete config2;
}
