/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Log.h"
#include <stdio.h>


void test(void)
{
  Log *log;
  User *user;
  struct tm tmp1, tmp2;

  printf("Construct a log\n");
  log = new Log();

  printf("Analyse test.log\n");
  log->analyse("test.log");

  printf("\n");
  printf("Number of users : %i\n", log->getNbUsers());
  printf("Number of periods : %i\n", log->getNbPeriods());
  tmp1 = log->getStartDate();
  printf("Date of start : %s", asctime(&tmp1));
  tmp2 = log->getEndDate();
  printf("Date de end : %s", asctime(&tmp2));
  printf("Number of sessions : %i\n", log->getNbSessions());
  printf("Number of nicknames : %i\n", log->getNbNicks());
  printf("Number of lines : %i\n", log->getNbLines());
  printf("Number of actions : %i\n", log->getNbActions());
  printf("Number of topics : %i\n", log->getNbTopics());
  printf("Number of kicks : %i\n", log->getNbKicks());
  printf("\n");
  printf("Number of users on time during the period of the log : %i\n", 
	 log->getNbUsers(mktime(&tmp2) - 24 * 3600 * 10));
  printf("Number of users on time before the period of the log : %i\n", 
	 log->getNbUsers(mktime(&tmp1) - 3600));
  printf("Number of users on time after the period of the log : %i\n",
	 log->getNbUsers(mktime(&tmp2) + 3600));
  printf("\n");
  printf("Average of users on hour 11 : %i\n", log->getDailyNbUsers(11));
  printf("Average of users on hour -1 : %i\n", log->getDailyNbUsers(-1));
  printf("Average of users on hour 24 : %i\n", log->getDailyNbUsers(24));
  printf("\n");
  printf("Number of lines during a period that begins and ends in the period of the log : %i\n",
	 log->getNbLines(mktime(&tmp1) + 82 * 3600, mktime(&tmp1) + 3600 + 82 * 3600));
  printf("Number of lines during a period that begins before the period of the log : %i\n",
	 log->getNbLines(mktime(&tmp1) - 3600, mktime(&tmp1) + 3600));
  printf("Number of lines during a period that ends after the period of the log : %i\n", 
	 log->getNbLines(mktime(&tmp2) - 3600, mktime(&tmp2) + 3600));
  printf("Number of lines during a wrong period : %i\n",
	 log->getNbLines(mktime(&tmp2) - 3600, mktime(&tmp2) - 7200));
  printf("\n");
  printf("Average of lines between hour 11 and hour 12 : %i\n", log->getDailyNbLines(11, 12));
  printf("Average of lines between hour -1 and hour 20 : %i\n", log->getDailyNbLines(-1, 20));
  printf("Average of lines between hour 23 and hour 24 : %i\n", log->getDailyNbLines(23, 24));
  printf("Average of lines between hour 21 and hour 11 : %i\n", log->getDailyNbLines(21, 11));
  printf("\n");
  user = log->getUser(1);
  printf("Number of nicknames : %i\n", user->getNbNicks());
  printf("Most used nickname : %s\n", user->getMostUsedNick());
  printf("All nicknames : %s\n", user->getAllNicks());
  printf("Number of sessions : %i - %s\n", user->getNbSessions(), user->getLeaveSentence());
  printf("Duration : %i - %s\n", user->getDuration(), user->getDurationSentence());
  printf("Number of lines : %i - %s\n", user->getNbLines(), user->getLineSentence());
  printf("Number of topics : %i - %s\n", user->getNbTopics(), user->getTopicSentence());
  printf("Number of actions : %i - %s\n", user->getNbActions(), user->getActionSentence());
  printf("Number of kicks : %i - %s\n", user->getNbKicks(), user->getKickSentence());
  printf("Number of sessions kickeds : %i - %s\n", user->getNbKickeds(), user->getKickedSentence());
}


void main(void)
{
  printf("First test\n");
  test();
  printf("Second test\n");
  test();
}
