/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include <stdio.h>
#include "Page.h"


void main(void)
{
  Log *log;
  Page *page;
  LineTable *line;
  DurationTable *duration;
  ActionTable *action;
  NickTable *nick;
  TopicTable *topic;
  KickTable *kick;
  KickedTable *kicked;
  SessionTable *session;
  UsersChart *users;
  LinesChart *lines;
  DailyUsersChart *dailyUsers;
  DailyLinesChart *dailyLines;
  FILE *file;

  printf("Analyse of test.log\n");
  log = new Log();
  log->analyse("test.log");
  printf("\n");
  printf("Open file stat1.html\n");
  file = fopen("stat1.html", "w");
  if (file == NULL) printf("Error of file\n");
  else
    {
      printf("Construct a page with a background color\n");
      page = new Page("#888888", "Statistics");
      printf("Relative image directory : %s\n", page->getImageDirectory());
      printf("Background : %s\n", page->getBackground());
      printf("Title : %s\n", page->getTitle());
      printf("Has it an image : %i\n", page->hasImage());
      printf("Configure a page with a background color\n");
      page->configure("#777777", "Statistics generated with test.log");
      printf("Relative image directory : %s\n", page->getImageDirectory());
      printf("Background : %s\n", page->getBackground());
      printf("Title : %s\n", page->getTitle());
      printf("Has it an image : %i\n", page->hasImage());

      printf("Generate the head of page\n");
      page->makeHead(file, log);
      
      printf("Construct a table of lines\n");
      line = new LineTable("bars/", "bar.gif", "Who is talkative ?", 5, 0);
      printf("Relative image directory : %s\n", line->getImageDirectory());
      printf("Image : %s\n", line->getBarImage());
      printf("Title : %s\n", line->getTitle());
      printf("Maximum number of users : %i\n", line->getNbMaxUsers());
      printf("Does it show examples : %i\n", line->hasExamples());
      printf("Configure the table of lines\n");
      line->configure("images/", "hbar.gif", "Who is the most talkative ?", 15, 1);
      printf("Relative image directory : %s\n", line->getImageDirectory());
      printf("Image : %s\n", line->getBarImage());
      printf("Title : %s\n", line->getTitle());
      printf("Maximum number of users : %i\n", line->getNbMaxUsers());
      printf("Does it show examples : %i\n", line->hasExamples());
      line->generate(file, log);
      delete line;

      printf("Construct a table of duration\n");
      duration = new DurationTable("images/", "hbar.gif", "Who is the most present ?", 10, 1);
      duration->generate(file, log);
      delete duration;

      printf("Construct a table of actions\n");
      action = new ActionTable("images/", "hbar.gif", "Who is the most expressive ?", 15, 1);
      action->generate(file, log);
      delete action;

      printf("Construct a table of nicknames\n");
      nick = new NickTable("images/", "hbar.gif", "Who has a lot of nicknames ?", 15, 1);
      nick->generate(file, log);
      delete nick;

      printf("Construct a table of topics\n");
      topic = new TopicTable("images/", "hbar.gif", "Who often changes topic ?", 5, 1);
      topic->generate(file, log);
      delete topic;

      printf("Construct a table of kicks\n");
      kick = new KickTable("images/", "hbar.gif", "Who often kicks ?", 10, 1);
      kick->generate(file, log);
      delete kick;

      printf("Construct a table of kicked users\n");
      kicked = new KickedTable("images/", "hbar.gif", "Who is the most kicked ?", 10, 1);
      kicked->generate(file, log);
      delete kicked;

      printf("Construct a table of sessions\n");
      session = new SessionTable("images/", "hbar.gif", "Who often joins channel ?", 10, 1);
      session->generate(file, log);
      delete session;

      printf("Generate the bottom of page\n");
      page->makeBottom(file);

      fclose(file);
    }

  printf("Open file stat2.html\n");
  file = fopen("stat2.html", "w");
  if (file == NULL) printf("Error of file\n");
  else
    {
      printf("Configure a page with a background image\n");
      page->configure("images/", "back.jpeg", "Statistics generated with test.log");
      printf("Relative image directory : %s\n", page->getImageDirectory());
      printf("Background : %s\n", page->getBackground());
      printf("Title : %s\n", page->getTitle());
      printf("Has it an image : %i\n", page->hasImage());

      printf("Generate the head of page\n");
      page->makeHead(file, log);

      printf("Construct a chart of users\n");
      users = new UsersChart("bars/", "bar.gif", "When is there a lot of people ?", 10);
      printf("Relative image directory : %s\n", users->getImageDirectory());
      printf("Image : %s\n", users->getBarImage());
      printf("Title : %s\n", users->getTitle());
      printf("Hour of the day : %i\n", users->getHour());
      printf("Configure the chart of users\n");
      users->configure("images/", "vbar.gif", "When is there a lot of users ?", 15);
      printf("Relative image directory : %s\n", users->getImageDirectory());
      printf("Image : %s\n", users->getBarImage());
      printf("Title : %s\n", users->getTitle());
      printf("Hour of the day : %i\n", users->getHour());
      users->generate(file, log);
      delete users;

      printf("Construct a chart of lines\n");
      lines = new LinesChart("images/", "vbar.gif", "When did they speak ?");
      lines->generate(file, log);
      delete lines;
      
      printf("Construct a chart of daily users\n");
      dailyUsers = new DailyUsersChart("bar-images/", "bar2.gif", "When was there a lot of people ?", 2);
      printf("Relative image directory : %s\n", dailyUsers->getImageDirectory());
      printf("Image : %s\n", dailyUsers->getBarImage());
      printf("Title : %s\n", dailyUsers->getTitle());
      printf("Interval of hours : %i\n", dailyUsers->getInterval());
      printf("Configure a chart of daily users\n");
      dailyUsers->configure("images/", "vbar.gif", "When was there a lot of users ?", 1);
      printf("Relative image directory : %s\n", dailyUsers->getImageDirectory());
      printf("Image : %s\n", dailyUsers->getBarImage());
      printf("Title : %s\n", dailyUsers->getTitle());
      printf("Interval of hours : %i\n", dailyUsers->getInterval());
      dailyUsers->generate(file, log);
      delete dailyUsers;

      printf("Construct a chart of daily lines\n");
      dailyLines = new DailyLinesChart("images/", "vbar.gif", "When do they speak ?", 3);
      dailyLines->generate(file, log);
      delete dailyLines;

      printf("Generate the bottom of page\n");
      page->makeBottom(file);

      delete page;

      fclose(file);
    }

  printf("\n");
  printf("Delete log\n");
  delete log;
  printf("Log not null : %i\n", (log != NULL));
  printf("Construct of a log\n");
  log = new Log();
  printf("Log not null : %i\n", (log != NULL));
  printf("Number of users : %i\n", log->getNbUsers());
  printf("Number of periods : %i\n", log->getNbPeriods());
  printf("Analyse test.log\n");
  log->analyse("test.log");
}
