/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include <stdio.h>
#include "User.h"


User *user;


void makeSession(char nick[])
{
  int i;
  char *string = new char[50];

  printf("%s joins channel\n", nick);
  user->joins(nick, time(NULL));

  printf("%s speaks five times\n", nick);
  for (i = 0; i < 5; i++)
    {
      scanf("%s", string);
      user->speaks(string);
    }
 
  printf("%s sets 3 topics\n", nick);
  for (i = 0; i < 3; i++)
   {
     scanf("%s", string);
     user->changesTopic(string);
   }

  printf("%s does action once\n", nick);
  scanf("%s", string);
  user->doesAction(string);

  printf("%s kicks twice\n", nick);
  for (i = 0; i < 2; i++)
    {
      scanf("%s", string);
      user->kicks(string);
    }
}


void main(void)
{
  int i;
  char *string = new char[50];

  srand(time(0));
  printf("Construct an user\n");
  user = new User("tom", "provider.com");

  makeSession("Tommy");
  printf("Tommy leaves IRC\n");
  scanf("%s", string);
  user->leavesIRC(string, time(NULL));

  printf("Duration : %i - %s\n", user->getDuration(), user->getDurationSentence());

  makeSession("Tomy");
  printf("Has he the nickname Tommy : %i\n", user->compareNick("Tommy"));
  printf("Has he the nickname Tomy : %i\n", user->compareNick("Tomy"));
  printf("Tomy leaves\n");
  scanf("%s", string);
  user->leaves(time(NULL));

  printf("Duration : %i - %s\n", user->getDuration(), user->getDurationSentence());
  printf("Has he the address (mot, provider.net) : %i\n", user->compareAddress("mot", "provider.net"));
  printf("Has he the address (tom, provider.net) : %i\n", user->compareAddress("tom", "provider.net"));
  printf("Has he the address (mot, provider.com) : %i\n", user->compareAddress("mot", "provider.com"));
  printf("Has he the address (tom, provider.com) : %i\n", user->compareAddress("tom", "provider.com"));
  printf("Has he the address (~tom, provider.com) : %i\n", user->compareAddress("~tom", "provider.com"));

  makeSession("Tommy");
  printf("Tommy is kicked\n");
  scanf("%s", string);
  user->isKicked(string, time(NULL));

  printf("\n");
  printf("Number of sessions : %i - %s\n", user->getNbSessions(), user->getLeaveSentence());
  time_t t = time(NULL);
  printf("Was he present 3 sec ago : %i\n", user->wasPresent(t - 3));
  printf("Is he present now : %i\n", user->wasPresent(t + 1));
  printf("Number of nicknames : %i\n", user->getNbNicks());
  printf("Most used nickname : %s\n", user->getMostUsedNick());
  printf("All nicknames : %s\n", user->getAllNicks());
  printf("Duration : %i - %s\n", user->getDuration(), user->getDurationSentence());
  printf("Number of lines : %i - %s\n", user->getNbLines(), user->getLineSentence());
  printf("Number of topics : %i - %s\n", user->getNbTopics(), user->getTopicSentence());
  printf("Number of actions : %i - %s\n", user->getNbActions(), user->getActionSentence());
  printf("Number of kicks : %i - %s\n", user->getNbKicks(), user->getKickSentence());
  printf("Number of sessions kicked : %i - %s\n", user->getNbKickeds(), user->getKickedSentence());

  delete user;
}





