/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Page.h"


/*
 * Gets the number of users at a hour of a day.
 */
int UsersChart::getNumber(time_t aTime, Log *aLog)
{
  return aLog->getNbUsers(aTime + (hour * 3600));
}


/*
 * Constructs a chart of users.
 */
UsersChart::UsersChart(char anImageDirectory[], char aBarImage[], char aTitle[], int anHour) : Chart(anImageDirectory, aBarImage, aTitle)
{
  hour = anHour;
}


/*
 * Gets the hour of the day to determine the number of users.
 */
int UsersChart::getHour()
{
  return hour;
}


/*
 * Configures the chart of users.
 */
void UsersChart::configure(char anImageDirectory[], char aBarImage[], char aTitle[], int anHour)
{
  strcpy(imageDirectory, anImageDirectory);
  strcpy(barImage, aBarImage);
  strcpy(title, aTitle);
  hour = anHour;
}
