/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Window.h"


GtkWidget *window;
GtkWidget *eLog;
GtkWidget *rBgColor;
GtkWidget *eBgColor;
GtkWidget *rBgImage;
GtkWidget *eBgImage;
GtkWidget *eDirectory;
GtkWidget *eTitle;
GtkWidget *listFree;
gint      rowFree;
GtkWidget *listUsed;
gint      rowUsed;
GtkWidget *ePage;
Config    *config;


void finish()
{
  config->setLogName(gtk_entry_get_text(GTK_ENTRY(eLog)));
  config->setFileName(gtk_entry_get_text(GTK_ENTRY(ePage)));
  if (GTK_TOGGLE_BUTTON(rBgColor)->active) config->getPage()->configure(gtk_entry_get_text(GTK_ENTRY(eBgColor)),
									 gtk_entry_get_text(GTK_ENTRY(eTitle)));
  else config->getPage()->configure(gtk_entry_get_text(GTK_ENTRY(eDirectory)),
				    gtk_entry_get_text(GTK_ENTRY(eBgImage)),
				    gtk_entry_get_text(GTK_ENTRY(eTitle)));
}


void generate()
{
  Generate *gen;
  char *text1;
  char text2[30];

  finish();
  config->saveCurrent();
  
  gen = new Generate(config);
  text1 = gen->make();
  sprintf(text2, "  %s.  ", text1);
  createPopup(text2);

  delete gen;
}


void configure()
{
  gchar *text;
  gint i;
  if (rowUsed > -1)
    {
      gtk_clist_get_text(GTK_CLIST(listUsed), rowUsed, 0, &text);
      i = config->getNoStat(text);
      if (i > -1) createDialog(config, i);
    }
}


void free_selection_made( GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data )
{
        if (data == NULL) rowFree = row;
	else rowFree = -1;
}


void used_selection_made( GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data )
{
        if (data == NULL) rowUsed = row;
	else rowUsed = -1;
}


void add_item(gpointer data)
{
        gchar *text;
	gchar *tmp[1];
	if (rowFree > -1)
	  {
	    gtk_clist_get_text(GTK_CLIST(listFree), rowFree, 0, &text);
	    tmp[0] = text;
	    config->add(text);
	    gtk_clist_append(GTK_CLIST(listUsed), tmp);
	    gtk_clist_remove(GTK_CLIST(listFree), rowFree);
	  }
}


void remove_item(gpointer data)
{
        gchar *text;
	gchar *tmp[1];
	if (rowUsed > -1)
	  {
	    config->remove(rowUsed);
	    gtk_clist_get_text(GTK_CLIST(listUsed), rowUsed, 0, &text);
	    tmp[0] = text;
	    gtk_clist_append(GTK_CLIST(listFree), tmp);
	    gtk_clist_remove(GTK_CLIST(listUsed), rowUsed);
	  }
}


void go_up_item(gpointer data)
{
        gchar *text;
	gchar *tmp[1];
	gint row = rowUsed;
	if (row > 0)
	  {
	    config->go_up(row);
	    gtk_clist_get_text(GTK_CLIST(listUsed), row, 0, &text);
	    tmp[0] = text;
	    gtk_clist_insert(GTK_CLIST(listUsed), row - 1, tmp);
	    gtk_clist_remove(GTK_CLIST(listUsed), row + 1);
	    gtk_clist_select_row(GTK_CLIST(listUsed), row - 1, 0);
	  }
}


void go_down_item(gpointer data)
{
        gchar *text;
	gchar *tmp[1];
	gchar *text2;
	gint row = rowUsed;
	if (row > -1 && row < config->getNbUsed() - 1)
	  {
	    config->go_down(row);
	    gtk_clist_get_text(GTK_CLIST(listUsed), row, 0, &text);
	    tmp[0] = text;
	    gtk_clist_get_text(GTK_CLIST(listUsed), row + 2, 0, &text2);
	    if (&text2 != NULL) gtk_clist_insert(GTK_CLIST(listUsed), row + 2, tmp);
	                  else gtk_clist_append(GTK_CLIST(listUsed), tmp);
	    gtk_clist_remove(GTK_CLIST(listUsed), row);
	    gtk_clist_select_row(GTK_CLIST(listUsed), row + 1, 0);
	  }
}


void initialize()
{
  finish();
  config->loadCurrent();
  gtk_entry_set_text(GTK_ENTRY(eLog), config->getLogName());
  if (config->getPage()->hasImage())
    {
      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(rBgImage), TRUE);
      gtk_entry_set_text(GTK_ENTRY(eBgImage), config->getPage()->getBackground());
      gtk_entry_set_text(GTK_ENTRY(eDirectory), config->getPage()->getImageDirectory());
    }
  else
    {
      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(rBgColor), TRUE);
      gtk_entry_set_text(GTK_ENTRY(eBgColor), config->getPage()->getBackground());
    }
  gtk_entry_set_text(GTK_ENTRY(eTitle), config->getPage()->getTitle());

  gtk_clist_clear(GTK_CLIST(listFree));
  char *text = new char[50];
  for (int i = 0; i < config->getNbStats(); i++)
    {
      text = config->getStatName(i);
      if (!(config->isUsed(i))) gtk_clist_append(GTK_CLIST(listFree), &text);
    }
  rowFree = -1;
  gtk_clist_clear(GTK_CLIST(listUsed));
  for (int i = 0; i < config->getNbUsed(); i++)
    {
      text = config->getUsedStatName(i);
      gtk_clist_append(GTK_CLIST(listUsed), &text);
    }
  rowUsed = -1;

  gtk_entry_set_text(GTK_ENTRY(ePage), config->getFileName());
}


void quit()
{
  finish();
  config->saveCurrent();
  gtk_main_quit();
}


void createWindow(Config *aConfig)
{
	GtkWidget *vbox;	// main box
	GtkWidget *hbox;	// each line of widgets
	GtkWidget *widget;	// temporary widget
	GtkWidget *tmpbox;	// temporary box
	GtkWidget *tmphbox;	// temporary box
	GtkWidget *arrow;	// temporary arrow
      	char      *l;           // current language
	gchar     *messages[12];// messages


        // Gives the configuraton
        config = aConfig;

	// Initializes messages
	l = setlocale(LC_ALL, "");
	if (*l == 'f' && *(++l) == 'r')
	  {
	    messages[0] = "Fichier de log :";
	    messages[1] = "Fond de page :";
	    messages[2] = "Couleur :";
	    messages[3] = "Image :";
	    messages[4] = "Rpertoire relatif de l'image :";
	    messages[5] = "Titre :";
	    messages[6] = "Fichier gnr :";
	    messages[7] = "Parcourir...";
	    messages[8] = "Choisir...";
	    messages[9] = "Configurer...";
	    messages[10] = "Gnrer une page web";
	    messages[11] = "Quitter";
	  }
	else
	  {
	   messages[0] = "Log file :";
	   messages[1] = "Background :";
	   messages[2] = "Color :";
	   messages[3] = "Image :";
	   messages[4] = "Relative image directory :";
	   messages[5] = "Title :";
	   messages[6] = "Generated file :";
	   messages[7] = "Browse...";
	   messages[8] = "Choose...";
	   messages[9] = "Configure...";
	   messages[10] = "Generate web page";
	   messages[11] = "Exit";
	  }

	// the main window
	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title (GTK_WINDOW (window), "Xstat");
	gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(quit), NULL);

	// the main box
	vbox = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER (window), vbox);

	// the "Log file" line
	hbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);

	// the "Log file" label
	widget = gtk_label_new(messages[0]);
	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// the "Log file" entry
	eLog = gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(hbox), eLog, TRUE, TRUE, 5);
	gtk_widget_show(eLog);

	// the "Browse..." button for log file
	widget= gtk_button_new_with_label(messages[7]);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(createBrowse), eLog);
	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// display of the "Log file" line
	gtk_widget_show(hbox);

	// the "Background" line
	hbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);

	// the "Background" label
	widget = gtk_label_new(messages[1]);
	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// the choice box
	tmpbox = gtk_vbox_new(TRUE, 5);
	gtk_box_pack_start(GTK_BOX(hbox), tmpbox, TRUE, TRUE, 5);

	// the "Color" line
	tmphbox = gtk_hbox_new(FALSE, 10);
	gtk_box_pack_start(GTK_BOX(tmpbox), tmphbox, TRUE, TRUE, 0);

	// the "Color" label
	rBgColor = gtk_radio_button_new_with_label(NULL, messages[2]);
	gtk_box_pack_start(GTK_BOX(tmphbox), rBgColor, FALSE, FALSE, 5);
	gtk_widget_show(rBgColor);

	// the "Color" entry
	eBgColor = gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(tmphbox), eBgColor, TRUE, TRUE, 5);
	gtk_widget_show(eBgColor);

	// the "Choose..." button for color background
	widget= gtk_button_new_with_label (messages[8]);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(createChoose), eBgColor);
	gtk_box_pack_start(GTK_BOX(tmphbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// display of the "Color" line
	gtk_widget_show(tmphbox);

	// the "Image" line
	tmphbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(tmpbox), tmphbox, TRUE, TRUE, 0);

	// the "Image" label
	rBgImage = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON (rBgColor)), messages[3]);
	gtk_box_pack_start(GTK_BOX(tmphbox), rBgImage, FALSE, FALSE, 5);
	gtk_widget_show(rBgImage);

	// the "Image" entry
	eBgImage = gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(tmphbox), eBgImage, TRUE, TRUE, 5);
	gtk_widget_show(eBgImage);

	// the "Browse..." button for image background
	widget= gtk_button_new_with_label (messages[7]);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(createBrowseImage), eBgImage);
	gtk_box_pack_start(GTK_BOX(tmphbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// display of the "Image" line
	gtk_widget_show(tmphbox);

	// the "Directory" line
	tmphbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(tmpbox), tmphbox, TRUE, TRUE, 0);

	// the "Directory" label
	widget = gtk_label_new(messages[4]);
	gtk_box_pack_start(GTK_BOX(tmphbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// the "Directory" entry
	eDirectory = gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(tmphbox), eDirectory, TRUE, TRUE, 5);
	gtk_widget_show(eDirectory);

	// display of the "Directory" line
	gtk_widget_show(tmphbox);

	// display of the choice line
	gtk_widget_show(tmpbox);

	// display of the "Background" line
	gtk_widget_show(hbox);

	// the "Title" line
	hbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);

	// the "Title" label
	widget = gtk_label_new(messages[5]);
	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// the "Title" entry
	eTitle = gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(hbox), eTitle, TRUE, TRUE, 5);
	gtk_widget_show(eTitle);

	// display of the "Title" line
	gtk_widget_show(hbox);

	// the "Lists" line
	hbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);

	// the "Free" list
	listFree = gtk_clist_new (1);
	gtk_clist_set_column_width (GTK_CLIST(listFree), 0, 300);
	gtk_signal_connect(GTK_OBJECT(listFree), "select_row", GTK_SIGNAL_FUNC(free_selection_made), NULL);
	gtk_signal_connect(GTK_OBJECT(listFree), "unselect_row", GTK_SIGNAL_FUNC(free_selection_made), listFree);
	gtk_box_pack_start(GTK_BOX(hbox), listFree, TRUE, TRUE, 5);
	gtk_widget_show(listFree);

	// the center column
	tmpbox = gtk_vbox_new(TRUE, 25);
	gtk_box_pack_start(GTK_BOX(hbox), tmpbox, FALSE, FALSE, 5);

	// the right button
	widget = gtk_button_new();
	arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
	gtk_container_add (GTK_CONTAINER (widget), arrow);
	gtk_widget_show(arrow);
	gtk_signal_connect_object(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(add_item), NULL);
	gtk_box_pack_start(GTK_BOX(tmpbox), widget, TRUE, TRUE, 25);
	gtk_widget_show(widget);

	// the left button
	widget = gtk_button_new();
	arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
	gtk_container_add (GTK_CONTAINER (widget), arrow);
	gtk_widget_show(arrow);
	gtk_signal_connect_object(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(remove_item), NULL);
	gtk_box_pack_start(GTK_BOX(tmpbox), widget, TRUE, TRUE, 25);
	gtk_widget_show(widget);

	// display of the center column
	gtk_widget_show(tmpbox);

	// the "Used" list
	listUsed = gtk_clist_new (1);
	gtk_clist_set_column_width (GTK_CLIST(listUsed), 0, 300);
	gtk_signal_connect(GTK_OBJECT(listUsed), "select_row", GTK_SIGNAL_FUNC(used_selection_made), NULL);
	gtk_signal_connect(GTK_OBJECT(listUsed), "unselect_row", GTK_SIGNAL_FUNC(used_selection_made), listUsed);
	gtk_box_pack_start(GTK_BOX(hbox), listUsed, TRUE, TRUE, 5);
	gtk_widget_show(listUsed);

	// the right column
	tmpbox = gtk_vbox_new(TRUE, 25);
	gtk_box_pack_start(GTK_BOX(hbox), tmpbox, FALSE, FALSE, 5);

	// the up button
	widget= gtk_button_new();
	arrow = gtk_arrow_new(GTK_ARROW_UP, GTK_SHADOW_OUT);
	gtk_container_add (GTK_CONTAINER (widget), arrow);
	gtk_widget_show(arrow);
	gtk_signal_connect_object(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(go_up_item), NULL);
	gtk_box_pack_start(GTK_BOX(tmpbox), widget, TRUE, TRUE, 25);
	gtk_widget_show(widget);

	// the down button
	widget= gtk_button_new();
	arrow = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_OUT);
	gtk_container_add (GTK_CONTAINER (widget), arrow);
	gtk_widget_show(arrow);
	gtk_signal_connect_object(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(go_down_item), NULL);
	gtk_box_pack_start(GTK_BOX(tmpbox), widget, TRUE, TRUE, 25);
	gtk_widget_show(widget);

	// display of the left column
	gtk_widget_show(tmpbox);

	// display of the "Lists" line
	gtk_widget_show(hbox);

	// the "Configure..." line
	hbox = gtk_hbox_new(TRUE, 5);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);

	// an invisible label
	widget = gtk_label_new("");
	gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 5);
	gtk_widget_show(widget);

	// the "Configure..." button
	widget = gtk_button_new_with_label(messages[9]);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(configure), NULL);
	gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 5);
	gtk_widget_show(widget);

	// display of the "Configure..." line
	gtk_widget_show(hbox);

	// the "Generated file" line
	hbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);

	// the "Generated file" label
	widget = gtk_label_new(messages[6]);
	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// the "Generated file" entry
	ePage = gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(hbox), ePage, TRUE, TRUE, 5);
	gtk_widget_show(ePage);

	// the "Browse..." button for generated file
	widget= gtk_button_new_with_label (messages[7]);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(createBrowse), ePage);
	gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 5);
	gtk_widget_show(widget);

	// display of the "Generated file" line
	gtk_widget_show(hbox);

	// the "buttons" line
	hbox = gtk_hbox_new(FALSE, 5);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 10);

	// the "Generate web page" button
	widget= gtk_button_new_with_label (messages[10]);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(generate), NULL);
	//gtk_signal_connect(GTK_OBJECT(widget), "released", GTK_SIGNAL_FUNC(generate), NULL);
	gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 5);
	gtk_widget_show(widget);

	// the "Exit" button
	widget= gtk_button_new_with_label(messages[11]);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked", GTK_SIGNAL_FUNC(quit), NULL);
	gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 5);
	gtk_widget_show(widget);

	// display of the "button" line
	gtk_widget_show(hbox);

	// display of the main box
	gtk_widget_show(vbox);

	// display of the main window
	gtk_widget_show(window);

	initialize();
}
